_`umbra.components.addons.projectsExplorer.views`
=================================================

.. automodule:: umbra.components.addons.projectsExplorer.views

Module Attributes
-----------------

.. attribute:: umbra.components.addons.projectsExplorer.views.LOGGER

Classes
-------

.. autoclass:: Projects_QTreeView
	:show-inheritance:
	:members:

